========================
FeinCMS Template Content
========================

FeinCMS content types with (optionally) selectable templates.
(this project is not endorsed by FeinCMS).

Use the TemplateContent class a base class for your template based content
types in FeinCMS. The template used is selectable in the admin panel.


Installation
============

Use your favorite method to get it from pypi, for example:

::

    pip install feincms-template-content

if you want to use the bundled RichTextContent's templates you'll need to add
``feincms_template_content`` to your ``INSTALLED_APPS``.
